@@ -4,7 +4,9 @@
 #include <QWidget>
 
 class QGridLayout;
+class QStackedWidget;
 class QCheckBox;
+class QComboBox;
 class QPushButton;
 class QLabel;
 class QLineEdit;
@@ -19,7 +21,8 @@ public:
 	EditInterface(MainWindow *main, ProcessRunner *runner);
 
 public slots:
-	void configure(void);
+	void configure0();
+	void configure();
 
 private slots:
 	void toggleDhcp(int state);
@@ -30,8 +33,12 @@ private:
 	ProcessRunner *m_runner;
 
 	QGridLayout *m_layout;
-	QCheckBox *m_dhcp;
+	enum { DHCP_SERVER = 0, DHCP_CLIENT, DHCP_STATIC };
+	QComboBox *m_dhcp;
+	QStackedWidget *m_stack;
 	QCheckBox *m_route;
+	QLabel *m_peerip;
+	QLabel *m_defroute;
         QPushButton *m_configure;
 	QPushButton *m_cancel;
 	QLabel *m_ipaddress;
