@@ -1,3 +1,4 @@
+#include <QApplication>
 #include <QVBoxLayout>
 #include <QStackedWidget>
 #include <QFrame>
@@ -11,8 +12,9 @@
 #include "passwd.h"
 #include "usbmanage.h"
 
-MainWindow::MainWindow(QObject *parent)
+MainWindow::MainWindow(QApplication *parent)
 {
+	m_app = parent;
 	m_mainlayout = new QVBoxLayout;
 	m_separator = new QFrame;
 	m_runner = new ProcessRunner;
@@ -87,3 +89,12 @@ MainWindow::showUsbManage(void)
 	m_netinterfaces->setEditButtonEnabled(false);
 	m_stack->setCurrentIndex(USB);
 }
+
+// Hmm, if help window was child of this this method
+// would not have been written...
+void
+MainWindow::closeEvent(QCloseEvent * event)
+{
+    (void)event;
+    m_app->quit();
+}
