@@ -6,6 +6,7 @@
 class QVBoxLayout;
 class QStackedWidget;
 class QFrame;
+class QApplication;
 
 class NetInterfaces;
 class Launcher;
@@ -19,7 +20,7 @@ class MainWindow : public QWidget
      Q_OBJECT
 
 public:
-     MainWindow(QObject *parent=0);
+     MainWindow(QApplication *parent);
 
 public slots:
 	void showEdit(void);
@@ -29,23 +30,26 @@ public slots:
 	void activateLauncher(void);
 
 private:
-     QVBoxLayout *m_mainlayout;
-     QFrame *m_separator; // separator line for top and bottom
+	QApplication * m_app;
+	QVBoxLayout *m_mainlayout;
+	QFrame *m_separator; // separator line for top and bottom
 
-     // Allways visible at top of window
-     NetInterfaces *m_netinterfaces;
+	// Always visible at top of window
+	NetInterfaces *m_netinterfaces;
 
-     QStackedWidget *m_stack;
+	QStackedWidget *m_stack;
 
      // One of these is visible at bottom of window.
-     enum { LAUNCHER = 0, PASSWD, USB, EDIT };
-     Launcher *m_launcher;
-     Passwd *m_passwd;
-     UsbManage *m_usbmanage;
-     EditInterface *m_editinterface;
+	enum { LAUNCHER = 0, PASSWD, USB, EDIT };
+	Launcher *m_launcher;
+	Passwd *m_passwd;
+	UsbManage *m_usbmanage;
+	EditInterface *m_editinterface;
 
-     // Shared script runner for m_netinterfaces and m_editinterface
-     ProcessRunner *m_runner;
+	// Shared script runner for m_netinterfaces and m_editinterface
+	ProcessRunner *m_runner;
+
+	void closeEvent(QCloseEvent * event);
 };
 
 #endif
