@@ -21,7 +21,7 @@ NetInterfaces::NetInterfaces(MainWindow *main, ProcessRunner *runner)
 	connect(m_runner, SIGNAL(finished(int)),
 		this, SLOT(dataAvailable(int)));
 
-	updateInterfaces();
+	//updateInterfaces(0); // done from usbmodule at startup, always.
 }
 
 class niLabel : public QLabel
@@ -83,8 +83,11 @@ NetInterfaces::clear()
 }
 
 void
-NetInterfaces::updateInterfaces(void)
+NetInterfaces::updateInterfaces(int do_config_ifaces)
 {
+    if (do_config_ifaces)
+	emit config_ifaces();
+    else
 	m_runner->start(QString("./interfaces.sh"), (QStringList)0);
 }
 
@@ -125,5 +128,5 @@ NetInterfaces::mousePressEvent(QMouseEvent * event)
 	(void)event;
 	setMinimumHeight(height());
 	clear();
-	updateInterfaces();
+	updateInterfaces(0);
 }
